@@ -13,22 +13,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from django.conf.urls import url
+
 from solumdashboard.languagepacks import views
-from solumdashboard.utils import importutils
 
-urls = importutils.import_any('django.conf.urls.defaults',
-                              'django.conf.urls')
-
-
-patterns = urls.patterns
-url = urls.url
-
-
-urlpatterns = patterns(
-    '',
+urlpatterns = [
     url(r'^$', views.IndexView.as_view(), name='index'),
     url(r'^$', views.IndexView.as_view(), name='languagepacks'),
     url(r'^detail/(?P<languagepack_id>[^/]+)$',
         views.DetailView.as_view(), name='detail'),
     url(r'^create$', views.CreateView.as_view(), name='create')
-)
+]
